"""PyConZA 2014 Demo"""

__author__ = 'Michael Joseph'
__email__ = 'michaeljoseph@gmail.com'
__url__ = 'https://github.com/michaeljoseph/pyconza2014'
__version__ = '0.1.0'


def pyconza2014():
    return 'Hello World!'
